@@ -17,11 +17,16 @@ test_that('all tests conform to the decrees of the God of Stats', {
 
   # Compare IMD-ANOVAly --------------------------------------------------------
 
+  # NOTE: There are three numbers that follow each object's name. The first
+  # number represents the number of main effects. The second number represents
+  # the number of covariates. The third represents the number of groups (across
+  # all main effects).
+  
   # Default comparisons ---------------
 
-  afruit_1_0_2 <- imd_anova(afilta_1_0_2, test_method = "anova")
-  gfruit_1_0_2 <- imd_anova(gfilta_1_0_2, test_method = "gtest")
-  cfruit_1_0_2 <- imd_anova(cfilta_1_0_2, test_method = "combined")
+  afruit_1_0_2 <- imd_anova(afilta_1_0_2, test_method = "anova", model_selection = "auto")
+  gfruit_1_0_2 <- imd_anova(gfilta_1_0_2, test_method = "gtest", model_selection = "auto")
+  cfruit_1_0_2 <- imd_anova(cfilta_1_0_2, test_method = "combined", model_selection = "auto")
 
   afruit_1_1_3 <- imd_anova(afilta_1_1_3,
     test_method = "anova"
@@ -35,47 +40,54 @@ test_that('all tests conform to the decrees of the God of Stats', {
   )
 
   afruit_1_2_3 <- imd_anova(afilta_1_2_3,
-    test_method = "anova"
+    test_method = "anova",
   )
   gfruit_1_2_3 <- imd_anova(gfilta_1_2_3,
     test_method = "gtest",
     parallel = FALSE
   )
   cfruit_1_2_3 <- imd_anova(cfilta_1_2_3,
-    test_method = "combined"
+    test_method = "combined",
   )
 
-  afruit_2_0_3 <- imd_anova(afilta_2_0_3, test_method = "anova")
-  gfruit_2_0_3 <- imd_anova(gfilta_2_0_3, test_method = "gtest")
-  cfruit_2_0_3 <- imd_anova(cfilta_2_0_3, test_method = "combined")
+  afruit_2_0_3 <- imd_anova(afilta_2_0_3, test_method = "anova", model_selection = "auto")
+  gfruit_2_0_3 <- imd_anova(gfilta_2_0_3, test_method = "gtest", model_selection = "auto")
+  cfruit_2_0_3 <- imd_anova(cfilta_2_0_3, test_method = "combined", model_selection = "auto")
 
   afruit_2_1_4 <- imd_anova(afilta_2_1_4,
-    test_method = "anova"
+    test_method = "anova",
+    model_selection = "auto"
   )
   gfruit_2_1_4 <- imd_anova(gfilta_2_1_4,
     test_method = "gtest",
+    model_selection = "auto",
     parallel = FALSE
   )
   cfruit_2_1_4 <- imd_anova(cfilta_2_1_4,
-    test_method = "combined"
+    test_method = "combined",
+    model_selection = "auto"
   )
 
   afruit_2_2_4 <- imd_anova(afilta_2_2_4,
-    test_method = "anova"
+    test_method = "anova",
+    model_selection = "auto"
   )
   gfruit_2_2_4 <- imd_anova(gfilta_2_2_4,
     test_method = "gtest",
+    model_selection = "auto",
     parallel = FALSE
   )
   cfruit_2_2_4 <- imd_anova(cfilta_2_2_4,
-    test_method = "combined"
+    test_method = "combined",
+    model_selection = "auto"
   )
 
   # Custom comparisons ---------------
 
   afruit_cus_2_0_3 <- imd_anova(
     omicsData = afilta_2_0_3,
-    comparisons = data.frame(
+    model_selection = "auto",
+    comparisons = data.frame(check.names = FALSE, 
       Control = c(
         "Infection_low",
         "Mock_none",
@@ -92,7 +104,8 @@ test_that('all tests conform to the decrees of the God of Stats', {
 
   gfruit_cus_2_0_3 <- imd_anova(
     omicsData = gfilta_2_0_3,
-    comparisons = data.frame(
+    model_selection = "auto",
+    comparisons = data.frame(check.names = FALSE, 
       Control = c(
         "Infection_low",
         "Mock_none",
@@ -168,14 +181,17 @@ test_that('all tests conform to the decrees of the God of Stats', {
 
   afruit_bon_2_0_3 <- imd_anova(afilta_2_0_3,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "bonferroni"
   )
   afruit_holm_2_0_3 <- imd_anova(afilta_2_0_3,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "holm"
   )
   afruit_tuk_2_0_3 <- imd_anova(afilta_2_0_3,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "tukey"
   )
   # Set a seed because the mvtnorm::pmvt function--which is called when doing a
@@ -183,6 +199,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   set.seed(4)
   afruit_dun_2_0_3 <- imd_anova(afilta_2_0_3,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "dunnett"
   )
   # Still gives an error even though all case-vs-control comparisons are being
@@ -192,14 +209,17 @@ test_that('all tests conform to the decrees of the God of Stats', {
 
   afruit_bon_2_1_4 <- imd_anova(afilta_2_1_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "bonferroni"
   )
   afruit_holm_2_1_4 <- imd_anova(afilta_2_1_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "holm"
   )
   afruit_tuk_2_1_4 <- imd_anova(afilta_2_1_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "tukey"
   )
   # Set a seed because the mvtnorm::pmvt function--which is called when doing a
@@ -207,19 +227,23 @@ test_that('all tests conform to the decrees of the God of Stats', {
   set.seed(8)
   afruit_dun_2_1_4 <- imd_anova(afilta_2_1_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "dunnett"
   )
 
   afruit_bon_2_2_4 <- imd_anova(afilta_2_2_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "bonferroni"
   )
   afruit_holm_2_2_4 <- imd_anova(afilta_2_2_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "holm"
   )
   afruit_tuk_2_2_4 <- imd_anova(afilta_2_2_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "tukey"
   )
   # Set a seed because the mvtnorm::pmvt function--which is called when doing a
@@ -227,6 +251,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   set.seed(11)
   afruit_dun_2_2_4 <- imd_anova(afilta_2_2_4,
     test_method = "anova",
+    model_selection = "auto",
     pval_adjust_a_multcomp = "dunnett"
   )
 
@@ -242,18 +267,22 @@ test_that('all tests conform to the decrees of the God of Stats', {
   )
   gfruit_bon_2_0_3 <- imd_anova(gfilta_2_0_3,
     test_method = "gtest",
+    model_selection = "auto",
     pval_adjust_g_multcomp = "bonferroni"
   )
   gfruit_holm_2_0_3 <- imd_anova(gfilta_2_0_3,
     test_method = "gtest",
+    model_selection = "auto",
     pval_adjust_g_multcomp = "holm"
   )
   gfruit_bon_2_1_4 <- imd_anova(gfilta_2_1_4,
     test_method = "gtest",
+    model_selection = "auto",
     pval_adjust_g_multcomp = "bonferroni"
   )
   gfruit_holm_2_1_4 <- imd_anova(gfilta_2_1_4,
     test_method = "gtest",
+    model_selection = "auto",
     pval_adjust_g_multcomp = "holm"
   )
 
@@ -304,7 +333,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   expect_equal(
     unclass(afruit_holm_1_1_3[, 11:13]),
     unclass(
-      data.frame(t(apply(astan_1_1_3[, 11:13],
+      data.frame(check.names = FALSE, t(apply(astan_1_1_3[, 11:13],
         1,
         p.adjust,
         method = "holm"
@@ -312,7 +341,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
     )
   )
   expect_equal(
-    data.frame(afruit_tuk_1_1_3[, 11:13]),
+    data.frame(check.names = FALSE, afruit_tuk_1_1_3[, 11:13]),
     tukey_pval_1_1_3
   )
   expect_true(
@@ -334,7 +363,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   expect_equal(
     unclass(afruit_holm_1_2_3[, 11:13]),
     unclass(
-      data.frame(t(apply(astan_1_2_3[, 11:13],
+      data.frame(check.names = FALSE, t(apply(astan_1_2_3[, 11:13],
         1,
         p.adjust,
         method = "holm"
@@ -342,7 +371,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
     )
   )
   expect_equal(
-    data.frame(afruit_tuk_1_2_3[, 11:13]),
+    data.frame(check.names = FALSE, afruit_tuk_1_2_3[, 11:13]),
     tukey_pval_1_2_3
   )
   expect_true(
@@ -362,7 +391,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   expect_equal(
     unclass(afruit_holm_2_0_3[, 11:13]),
     unclass(
-      data.frame(t(apply(astan_2_0_3[, 11:13],
+      data.frame(check.names = FALSE, t(apply(astan_2_0_3[, 11:13],
         1,
         p.adjust,
         method = "holm"
@@ -370,7 +399,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
     )
   )
   expect_equal(
-    data.frame(afruit_tuk_2_0_3[, 11:13]),
+    data.frame(check.names = FALSE, afruit_tuk_2_0_3[, 11:13]),
     tukey_pval_2_0_3
   )
   # Because of the random process in the mvtnorm::pmvt function we test the
@@ -402,7 +431,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   expect_equal(
     unclass(afruit_holm_2_1_4[, 16:21]),
     unclass(
-      data.frame(t(apply(astan_2_1_4[, 16:21],
+      data.frame(check.names = FALSE, t(apply(astan_2_1_4[, 16:21],
         1,
         p.adjust,
         method = "holm"
@@ -410,7 +439,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
     )
   )
   expect_equal(
-    data.frame(afruit_tuk_2_1_4[, 16:21]),
+    data.frame(check.names = FALSE, afruit_tuk_2_1_4[, 16:21]),
     tukey_pval_2_1_4
   )
   expect_true(
@@ -432,7 +461,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
   expect_equal(
     unclass(afruit_holm_2_2_4[, 16:21]),
     unclass(
-      data.frame(t(apply(astan_2_2_4[, 16:21],
+      data.frame(check.names = FALSE, t(apply(astan_2_2_4[, 16:21],
         1,
         p.adjust,
         method = "holm"
@@ -440,7 +469,7 @@ test_that('all tests conform to the decrees of the God of Stats', {
     )
   )
   expect_equal(
-    data.frame(afruit_tuk_2_2_4[, 16:21]),
+    data.frame(check.names = FALSE, afruit_tuk_2_2_4[, 16:21]),
     tukey_pval_2_2_4
   )
   expect_true(
@@ -470,13 +499,13 @@ test_that('all tests conform to the decrees of the God of Stats', {
     c(apply(data.frame(afruit_1_2_3$P_value_A_zombie_vs_human), 2, p.adjust, method = "bonferroni"))
   )
 
-  afruit_fdr_bon_2_0_3 <- imd_anova(afilta_2_0_3, test_method = "anova", pval_adjust_a_fdr = "bonferroni")
+  afruit_fdr_bon_2_0_3 <- imd_anova(afilta_2_0_3, test_method = "anova", pval_adjust_a_fdr = "bonferroni", model_selection = "auto")
   expect_equal(
     afruit_fdr_bon_2_0_3$P_value_A_Infection_high_vs_Mock_none,
     c(apply(data.frame(afruit_2_0_3$P_value_A_Infection_high_vs_Mock_none), 2, p.adjust, method = "bonferroni"))
   )
 
-  afruit_fdr_bon_2_1_4 <- imd_anova(afilta_2_1_4, test_method = "anova", pval_adjust_a_fdr = "bonferroni")
+  afruit_fdr_bon_2_1_4 <- imd_anova(afilta_2_1_4, test_method = "anova", pval_adjust_a_fdr = "bonferroni", model_selection = "auto")
   expect_equal(
     afruit_fdr_bon_2_1_4$P_value_A_Infection_high_vs_Infection_low,
     c(apply(data.frame(afruit_2_1_4$P_value_A_Infection_high_vs_Infection_low), 2, p.adjust, method = "bonferroni"))
@@ -509,12 +538,12 @@ test_that('all tests conform to the decrees of the God of Stats', {
   # G-Test: Adjusted p-values ---------------
 
   expect_equal(
-    data.frame(gfruit_bon_2_0_3[, 11:13]),
-    data.frame(pmin(data.matrix(gstan_2_0_3[, 11:13] * 3), 1))
+    data.frame(check.names = FALSE, gfruit_bon_2_0_3[, 11:13]),
+    data.frame(check.names = FALSE, pmin(data.matrix(gstan_2_0_3[, 11:13] * 3), 1))
   )
   expect_equal(
-    data.frame(gfruit_holm_2_0_3[, 11:13]),
-    data.frame(t(apply(gstan_2_0_3[, 11:13],
+    data.frame(check.names = FALSE, gfruit_holm_2_0_3[, 11:13]),
+    data.frame(check.names = FALSE, t(apply(gstan_2_0_3[, 11:13],
       1,
       p.adjust,
       method = "holm"
@@ -522,12 +551,12 @@ test_that('all tests conform to the decrees of the God of Stats', {
   )
 
   expect_equal(
-    data.frame(gfruit_bon_2_1_4[, 16:21]),
-    data.frame(pmin(data.matrix(gstan_2_1_4[, 16:21] * 6), 1))
+    data.frame(check.names = FALSE, gfruit_bon_2_1_4[, 16:21]),
+    data.frame(check.names = FALSE, pmin(data.matrix(gstan_2_1_4[, 16:21] * 6), 1))
   )
   expect_equal(
-    data.frame(gfruit_holm_2_1_4[, 16:21]),
-    data.frame(t(apply(gstan_2_1_4[, 16:21],
+    data.frame(check.names = FALSE, gfruit_holm_2_1_4[, 16:21]),
+    data.frame(check.names = FALSE, t(apply(gstan_2_1_4[, 16:21],
       1,
       p.adjust,
       method = "holm"
@@ -617,4 +646,88 @@ test_that('all tests conform to the decrees of the God of Stats', {
     "No IMD-ANOVA filter has been applied"
   )
  
+  ### Test that the default 'full' model_selection is equal when which_X is 1 and unequal otherwise for two factor cases.
+  afruit_2_1_4_full <- imd_anova(afilta_2_1_4,
+    test_method = "anova",
+    model_selection = "full"
+  )
+  
+  # check equality of indices where auto uses the full model
+  full_idx = attr(afruit_2_1_4, 'which_X') == 1
+  
+  expect_equal(
+    data.frame(afruit_2_1_4[full_idx,]),
+    data.frame(afruit_2_1_4_full[full_idx,])
+  )
+  
+  # check non-equality of indices where auto does the reduced model
+  truth_df = data.frame(afruit_2_1_4[!full_idx,]) == data.frame(afruit_2_1_4_full[!full_idx,])
+
+  pval_idx = grep("^P_value", colnames(truth_df))
+  mean_idx = grep("^Mean", colnames(truth_df))
+  all_idx = c(pval_idx, mean_idx)
+  
+  # It is technically possible some of these are the same or very similar....just check that most of them are not
+  expect_true(mean(truth_df[, all_idx], na.rm=T) < 0.001)
+  
+  afruit_2_2_4_full <- imd_anova(afilta_2_2_4,
+    test_method = "anova",
+    model_selection = "full"
+  )
+
+  full_idx = attr(afruit_2_2_4, 'which_X') == 1
+  
+  expect_equal(
+    data.frame(afruit_2_2_4[full_idx,]),
+    data.frame(afruit_2_2_4_full[full_idx,])
+  )
+  
+  truth_df = data.frame(afruit_2_2_4[!full_idx,]) == data.frame(afruit_2_2_4_full[!full_idx,])
+  
+  pval_idx = grep("^P_value", colnames(truth_df))
+  mean_idx = grep("^Mean", colnames(truth_df))
+  all_idx = c(pval_idx, mean_idx)
+  
+  expect_true(mean(truth_df[, all_idx], na.rm=T) < 0.001)
+  
+  # Same equality checks for combined method
+  cfruit_2_1_4_full <- imd_anova(cfilta_2_1_4,
+    test_method = "combined",
+    model_selection = "full"
+  )
+  
+  full_idx = attr(cfruit_2_1_4, 'which_X') == 1
+  
+  expect_equal(
+    data.frame(cfruit_2_1_4[full_idx,]),
+    data.frame(cfruit_2_1_4_full[full_idx,])
+  )
+  
+  truth_df = data.frame(cfruit_2_1_4[!full_idx,]) == data.frame(cfruit_2_1_4_full[!full_idx,])
+  
+  pval_idx = grep("^P_value_A", colnames(truth_df))
+  mean_idx = grep("^Mean", colnames(truth_df))
+  all_idx = c(pval_idx, mean_idx)
+  
+  expect_true(mean(truth_df[, all_idx], na.rm=T) < 0.001)
+  
+  cfruit_2_2_4_full <- imd_anova(cfilta_2_2_4,
+    test_method = "combined",
+    model_selection = "full"
+  )
+  
+  full_idx = attr(cfruit_2_2_4, 'which_X') == 1
+  
+  expect_equal(
+    data.frame(cfruit_2_2_4[full_idx,]),
+    data.frame(cfruit_2_2_4_full[full_idx,])
+  )
+  
+  truth_df = data.frame(cfruit_2_2_4[!full_idx,]) == data.frame(cfruit_2_2_4_full[!full_idx,])
+  
+  pval_idx = grep("^P_value_A", colnames(truth_df))
+  mean_idx = grep("^Mean", colnames(truth_df))
+  all_idx = c(pval_idx, mean_idx)
+  
+  expect_true(mean(truth_df[, all_idx], na.rm=T) < 0.001)
 })
